@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.345';
+$Config::Model::TkUI::VERSION = '1.346';
 use 5.10.1;
 use strict;
 use warnings;
@@ -253,6 +253,16 @@ sub Populate {
 
     my $find_frame = $cw->create_find_widget;
 
+    # create frame for message
+    my $msg_label = $cw->Label(
+        -textvariable => \$cw->{message},
+        -font => '-*-Helvetica-normal-R-Normal-*-*-120-*-*-*-*-*-*',
+        -relief => 'sunken',
+        -borderwidth => 1,
+        -anchor =>'w',
+    );
+    $msg_label->pack( -pady => 0, -fill => 'x' );
+
     $args->{-title} = $title;
     $cw->SUPER::Populate($args);
 
@@ -274,10 +284,23 @@ sub Populate {
     $cw->Advertise( right_frame => $eh_frame );
     $cw->Advertise( ed_frame    => $e_frame );
     $cw->Advertise( find_frame  => $find_frame );
+    $cw->Advertise( msg_label   => $msg_label );
 
     $cw->Delegates;
 }
 
+sub show_message {
+    my ( $cw, $msg ) = @_;
+    # $cw->Subwidget('msg_label')->configure(-background => "red"); # does not work
+    $cw->{message} = $msg;
+    my $unshow = sub {
+        my $id = delete $cw->{id};
+        $cw->afterCancel($id) if $id;
+        $cw->{message} = '';
+    } ;
+    $cw->{id} = $cw->after(5000,$unshow) ;
+}
+
 sub tree_width {
     my ( $cw, $value ) = @_;
     $cw->Subwidget('tree')->configure( -width => $value );
@@ -1383,11 +1406,11 @@ If you want to help, please send a mail to:
 
 =item *
 
-L<Config::Model>
+L<Config::Model>, L<cme>
 
 =item *
 
-http://config-model.wiki.sourceforge.net/
+https://github.com/dod38fr/config-model-tkui/wiki
 
 =item *
 
